summaryrefslogtreecommitdiff
path: root/hiredict_ssl.h
diff options
context:
space:
mode:
authorAnna (navi) Figueiredo Gomes <navi@vlhl.dev>2024-03-23 01:21:46 +0100
committerAnna (navi) Figueiredo Gomes <navi@vlhl.dev>2024-03-23 01:21:46 +0100
commitbb3475e8eb379ee18f3d8f37caa8040b852a6213 (patch)
tree89975f1c23814a7ab5e16f5c7887f55f1888a27a /hiredict_ssl.h
parentaee72918851db8af296e096b759dfb7aaea17968 (diff)
all: rename redis -> redict symbols and commentsmaster
Signed-off-by: Anna (navi) Figueiredo Gomes <navi@vlhl.dev>
Diffstat (limited to 'hiredict_ssl.h')
-rw-r--r--hiredict_ssl.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/hiredict_ssl.h b/hiredict_ssl.h
index 43f072a..73aa3c3 100644
--- a/hiredict_ssl.h
+++ b/hiredict_ssl.h
@@ -1,16 +1,16 @@
/*
- * Copyright (c) 2019, Redis Labs
+ * Copyright (c) 2019, Redict Labs
*
* SPDX-FileCopyrightText: 2024 Hiredict Contributors
- * SPDX-FileCopyrightText: 2024 Redis Labs
+ * SPDX-FileCopyrightText: 2024 Redict Labs
*
* SPDX-License-Identifier: BSD-3-Clause
* SPDX-License-Identifier: LGPL-3.0-or-later
*
*/
-#ifndef __HIREDIS_SSL_H
-#define __HIREDIS_SSL_H
+#ifndef __HIREDICT_SSL_H
+#define __HIREDICT_SSL_H
#ifdef __cplusplus
extern "C" {
@@ -24,34 +24,34 @@ struct ssl_st;
/* A wrapper around OpenSSL SSL_CTX to allow easy SSL use without directly
* calling OpenSSL.
*/
-typedef struct redisSSLContext redisSSLContext;
+typedef struct redictSSLContext redictSSLContext;
/**
* Initialization errors that redisCreateSSLContext() may return.
*/
typedef enum {
- REDIS_SSL_CTX_NONE = 0, /* No Error */
- REDIS_SSL_CTX_CREATE_FAILED, /* Failed to create OpenSSL SSL_CTX */
- REDIS_SSL_CTX_CERT_KEY_REQUIRED, /* Client cert and key must both be specified or skipped */
- REDIS_SSL_CTX_CA_CERT_LOAD_FAILED, /* Failed to load CA Certificate or CA Path */
- REDIS_SSL_CTX_CLIENT_CERT_LOAD_FAILED, /* Failed to load client certificate */
- REDIS_SSL_CTX_CLIENT_DEFAULT_CERT_FAILED, /* Failed to set client default certificate directory */
- REDIS_SSL_CTX_PRIVATE_KEY_LOAD_FAILED, /* Failed to load private key */
- REDIS_SSL_CTX_OS_CERTSTORE_OPEN_FAILED, /* Failed to open system certificate store */
- REDIS_SSL_CTX_OS_CERT_ADD_FAILED /* Failed to add CA certificates obtained from system to the SSL context */
-} redisSSLContextError;
+ REDICT_SSL_CTX_NONE = 0, /* No Error */
+ REDICT_SSL_CTX_CREATE_FAILED, /* Failed to create OpenSSL SSL_CTX */
+ REDICT_SSL_CTX_CERT_KEY_REQUIRED, /* Client cert and key must both be specified or skipped */
+ REDICT_SSL_CTX_CA_CERT_LOAD_FAILED, /* Failed to load CA Certificate or CA Path */
+ REDICT_SSL_CTX_CLIENT_CERT_LOAD_FAILED, /* Failed to load client certificate */
+ REDICT_SSL_CTX_CLIENT_DEFAULT_CERT_FAILED, /* Failed to set client default certificate directory */
+ REDICT_SSL_CTX_PRIVATE_KEY_LOAD_FAILED, /* Failed to load private key */
+ REDICT_SSL_CTX_OS_CERTSTORE_OPEN_FAILED, /* Failed to open system certificate store */
+ REDICT_SSL_CTX_OS_CERT_ADD_FAILED /* Failed to add CA certificates obtained from system to the SSL context */
+} redictSSLContextError;
/* Constants that mirror OpenSSL's verify modes. By default,
* REDIS_SSL_VERIFY_PEER is used with redisCreateSSLContext().
* Some Redis clients disable peer verification if there are no
* certificates specified.
*/
-#define REDIS_SSL_VERIFY_NONE 0x00
-#define REDIS_SSL_VERIFY_PEER 0x01
-#define REDIS_SSL_VERIFY_FAIL_IF_NO_PEER_CERT 0x02
-#define REDIS_SSL_VERIFY_CLIENT_ONCE 0x04
-#define REDIS_SSL_VERIFY_POST_HANDSHAKE 0x08
+#define REDICT_SSL_VERIFY_NONE 0x00
+#define REDICT_SSL_VERIFY_PEER 0x01
+#define REDICT_SSL_VERIFY_FAIL_IF_NO_PEER_CERT 0x02
+#define REDICT_SSL_VERIFY_CLIENT_ONCE 0x04
+#define REDICT_SSL_VERIFY_POST_HANDSHAKE 0x08
/* Options to create an OpenSSL context. */
typedef struct {
@@ -61,13 +61,13 @@ typedef struct {
const char *private_key_filename;
const char *server_name;
int verify_mode;
-} redisSSLOptions;
+} redictSSLOptions;
/**
* Return the error message corresponding with the specified error code.
*/
-const char *redisSSLContextGetError(redisSSLContextError error);
+const char *redictSSLContextGetError(redictSSLContextError error);
/**
* Helper function to initialize the OpenSSL library.
@@ -76,7 +76,7 @@ const char *redisSSLContextGetError(redisSSLContextError error);
* call this function only once, and only if OpenSSL is not directly initialized
* elsewhere.
*/
-int redisInitOpenSSL(void);
+int redictInitOpenSSL(void);
/**
* Helper function to initialize an OpenSSL context that can be used
@@ -99,45 +99,45 @@ int redisInitOpenSSL(void);
* (returning a NULL).
*/
-redisSSLContext *redisCreateSSLContext(const char *cacert_filename, const char *capath,
+redictSSLContext *redictCreateSSLContext(const char *cacert_filename, const char *capath,
const char *cert_filename, const char *private_key_filename,
- const char *server_name, redisSSLContextError *error);
+ const char *server_name, redictSSLContextError *error);
/**
* Helper function to initialize an OpenSSL context that can be used
* to initiate SSL connections. This is a more extensible version of redisCreateSSLContext().
*
* options contains a structure of SSL options to use.
*
* If error is non-null, it will be populated in case the context creation fails
* (returning a NULL).
*/
-redisSSLContext *redisCreateSSLContextWithOptions(redisSSLOptions *options,
- redisSSLContextError *error);
+redictSSLContext *redictCreateSSLContextWithOptions(redictSSLOptions *options,
+ redictSSLContextError *error);
/**
* Free a previously created OpenSSL context.
*/
-void redisFreeSSLContext(redisSSLContext *redis_ssl_ctx);
+void redictFreeSSLContext(redictSSLContext *redict_ssl_ctx);
/**
* Initiate SSL on an existing redisContext.
*
* This is similar to redisInitiateSSL() but does not require the caller
* to directly interact with OpenSSL, and instead uses a redisSSLContext
* previously created using redisCreateSSLContext().
*/
-int redisInitiateSSLWithContext(redisContext *c, redisSSLContext *redis_ssl_ctx);
+int redictInitiateSSLWithContext(redictContext *c, redictSSLContext *redict_ssl_ctx);
/**
* Initiate SSL/TLS negotiation on a provided OpenSSL SSL object.
*/
-int redisInitiateSSL(redisContext *c, struct ssl_st *ssl);
+int redictInitiateSSL(redictContext *c, struct ssl_st *ssl);
#ifdef __cplusplus
}
#endif
-#endif /* __HIREDIS_SSL_H */
+#endif /* __HIREDICT_SSL_H */
@@ -24,34 +24,34 @@ struct ssl_st;
/**
- * Initialization errors that redisCreateSSLContext() may return.
+ * Initialization errors that redictCreateSSLContext() may return.
*/
typedef enum {
@@ -24,34 +24,34 @@ struct ssl_st;
/* Constants that mirror OpenSSL's verify modes. By default,
- * REDIS_SSL_VERIFY_PEER is used with redisCreateSSLContext().
- * Some Redis clients disable peer verification if there are no
+ * REDICT_SSL_VERIFY_PEER is used with redictCreateSSLContext().
+ * Some Redict clients disable peer verification if there are no
* certificates specified.
*/
@@ -99,45 +99,45 @@ int redisInitOpenSSL(void);
/**
* Helper function to initialize an OpenSSL context that can be used
- * to initiate SSL connections. This is a more extensible version of redisCreateSSLContext().
+ * to initiate SSL connections. This is a more extensible version of redictCreateSSLContext().
*
* options contains a structure of SSL options to use.
@@ -99,45 +99,45 @@ int redisInitOpenSSL(void);
/**
- * Initiate SSL on an existing redisContext.
+ * Initiate SSL on an existing redictContext.
*
@@ -99,45 +99,45 @@ int redisInitOpenSSL(void);
*
- * This is similar to redisInitiateSSL() but does not require the caller
- * to directly interact with OpenSSL, and instead uses a redisSSLContext
- * previously created using redisCreateSSLContext().
+ * This is similar to redictInitiateSSL() but does not require the caller
+ * to directly interact with OpenSSL, and instead uses a redictSSLContext
+ * previously created using redictCreateSSLContext().
*/